@@ -8,9 +8,10 @@ from labstep.service.helpers import url_join, handleKeyword, getHeaders
 from labstep.entities.tag.model import Tag
 from labstep.service.request import requestService
 import labstep.generic.entity.repository as entityRepository
+from labstep.constants import UNSPECIFIED
 
 
-def getTags(user, count=1000, type=None, search_query=None, extraParams={}):
+def getTags(user, count=1000, type=UNSPECIFIED, search_query=UNSPECIFIED, extraParams={}):
     """
     Retrieve a list of the user's tags.
 
